diff --git a/test/expected/identity.out b/test/expected/identity.out
new file mode 100644
index 0000000..71d3e2d
--- /dev/null
+++ b/test/expected/identity.out
@@ -0,0 +1,7 @@
+connected
+# of rows inserted: 1
+Result set:
+1
+Result set:
+1	foobar
+disconnecting
diff --git a/test/src/identity-test.c b/test/src/identity-test.c
new file mode 100644
index 0000000..cc79e29
--- /dev/null
+++ b/test/src/identity-test.c
@@ -0,0 +1,61 @@
+/*
+ * Test @@identity
+ */
+#include <stdio.h>
+#include <stdlib.h>
+
+#include "common.h"
+
+int main(int argc, char **argv)
+{
+	SQLRETURN rc;
+	HSTMT hstmt = SQL_NULL_HSTMT;
+	char param1[100];
+	SQLLEN cbParam1;
+	SQLCHAR *sql;
+	int i;
+	SQLLEN rowcount;
+
+	test_connect();
+
+	rc = SQLAllocHandle(SQL_HANDLE_STMT, conn, &hstmt);
+	if (!SQL_SUCCEEDED(rc))
+	{
+		print_diag("failed to allocate stmt handle", SQL_HANDLE_DBC, conn);
+		exit(1);
+	}
+
+	/* Prepare a test table */
+	sql = "CREATE TEMPORARY TABLE tmptable (i serial primary key, t text)";
+	rc = SQLExecDirect(hstmt, (SQLCHAR *) sql, SQL_NTS);
+	CHECK_STMT_RESULT(rc, "SQLExecDirect failed while creating temp table", hstmt);
+
+	/* Insert some rows, using a prepared statement */
+	rc = SQLExecDirect(hstmt, (SQLCHAR *) "INSERT INTO tmptable (t) VALUES ('foobar'); ",
+					   SQL_NTS);
+	CHECK_STMT_RESULT(rc, "SQLExecDirect failed", hstmt);
+
+	rc = SQLRowCount(hstmt, &rowcount);
+	CHECK_STMT_RESULT(rc, "SQLRowCount failed", hstmt);
+	printf("# of rows inserted: %d\n", (int) rowcount);
+
+	rc = SQLExecDirect(hstmt, (SQLCHAR *) "SELECT @@IDENTITY AS last_insert", SQL_NTS);
+	CHECK_STMT_RESULT(rc, "SQLExecDirect failed", hstmt);
+
+	/* Fetch result */
+	print_result(hstmt);
+
+	rc = SQLFreeStmt(hstmt, SQL_CLOSE);
+	CHECK_STMT_RESULT(rc, "SQLFreeStmt failed", hstmt);
+
+	/* Print the contents of the table after the updates to verify */
+
+	rc = SQLExecDirect(hstmt, (SQLCHAR *) "SELECT * FROM tmptable", SQL_NTS);
+	CHECK_STMT_RESULT(rc, "SQLExecDirect failed", hstmt);
+	print_result(hstmt);
+
+	/* Clean up */
+	test_disconnect();
+
+	return 0;
+}
diff --git a/test/tests b/test/tests
index e908771..d00c7f3 100644
--- a/test/tests
+++ b/test/tests
@@ -24,6 +24,7 @@ TESTBINS = src/connect-test \
 	src/notice-test \
 	src/arraybinding-test \
 	src/insertreturning-test \
+	src/identity-test \
 	src/dataatexecution-test \
 	src/boolsaschar-test \
 	src/cvtnulldate-test \
